==> apache-geode-1.12.5-src.tgz: apache-geode-1.12.5-src/geode-core/src/test/java/org/apache/geode/internal/cache/NonLocalRegionEntryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache;

import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Matchers.eq;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.junit.Test;


public class NonLocalRegionEntryTest {

  @Test
  public void shouldBeMockable() throws Exception {
    NonLocalRegionEntry mockNonLocalRegionEntry = mock(NonLocalRegionEntry.class);
    RegionEntryContext mockRegionEntryContext = mock(RegionEntryContext.class);
    LocalRegion mockLocalRegion = mock(LocalRegion.class);
    Object valueInVM = new Object();
    Object valueOnDisk = new Object();

    when(mockNonLocalRegionEntry.getValueInVM(eq(mockRegionEntryContext))).thenReturn(valueInVM);
    when(mockNonLocalRegionEntry.getValueInVMOrDiskWithoutFaultIn(eq(mockLocalRegion)))
        .thenReturn(valueOnDisk);

    assertThat(mockNonLocalRegionEntry.getValueInVM(mockRegionEntryContext)).isSameAs(valueInVM);
    assertThat(mockNonLocalRegionEntry.getValueInVMOrDiskWithoutFaultIn(mockLocalRegion))
        .isSameAs(valueOnDisk);
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/test/java/org/apache/geode/internal/cache/NonLocalRegionEntryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache;

import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.junit.Test;


public class NonLocalRegionEntryTest {

  @Test
  public void shouldBeMockable() throws Exception {
    NonLocalRegionEntry mockNonLocalRegionEntry = mock(NonLocalRegionEntry.class);
    RegionEntryContext mockRegionEntryContext = mock(RegionEntryContext.class);
    LocalRegion mockLocalRegion = mock(LocalRegion.class);
    Object valueInVM = new Object();
    Object valueOnDisk = new Object();

    when(mockNonLocalRegionEntry.getValueInVM(eq(mockRegionEntryContext))).thenReturn(valueInVM);
    when(mockNonLocalRegionEntry.getValueInVMOrDiskWithoutFaultIn(eq(mockLocalRegion)))
        .thenReturn(valueOnDisk);

    assertThat(mockNonLocalRegionEntry.getValueInVM(mockRegionEntryContext)).isSameAs(valueInVM);
    assertThat(mockNonLocalRegionEntry.getValueInVMOrDiskWithoutFaultIn(mockLocalRegion))
        .isSameAs(valueOnDisk);
  }
}
